ACG <- function(N,Psi)

# This function simulates the Angular Central Gaussian (ACG) distribution
#
# Input:
# N: number of simulated random vectors
# Psi: (q x q) matrix of parameters of the angular central Gaussian distribution
# 
# Output:
#
# y: (nreps x q) matrix of nreps simulated vectors of length q
#
# Usage: 
# N <- 100
# qq <- 3
# b <- 1
# lambda_n <- c(.588,.421,0)
# A <- diag(lambda_n)
# Psinv = diag(qq) + (2/b) * A
# Psi = solve(Psinv)
# ysim <- ACG(N,Psi)
#
# Authors: Marco Bee, Roberto Benedetti, Giuseppe Espa
# This version: August 2016.

{
source('c:\\marco\\dropbox\\R\\norm_vec_mat.r')
require(mvtnorm)
qq = nrow(Psi)
y = matrix(0,N,qq)
x = rmvnorm(N,rep(0,qq),Psi)
y = x/norm_vec_mat(x)
y
}